dblstats
========

An easy to use async `dblstatistics.com <https://dblstatistics.com>`__
API wrapper.

README information
~~~~~~~~~~~~~~~~~~

Command execution
^^^^^^^^^^^^^^^^^

When commands that need to be executed are shown in this documentation,
optional command will be surrounded by brackets.

System specific command execution
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

Since python has a different command call on Linus and Windows we
specify both in the documentation.

::

    documentation: (py -3 | python3) command
    windows: py -3 command
    linux: python3 command

Installing
----------

To install the library you can just run the following pip command.

::

    (py -3 -m | python3 -m) pip install dblstats

Executing example scripts
-------------------------

Requirements
~~~~~~~~~~~~

The example scripts might be discord bots. If so execute the following
command to install the dependencies.

::

    (py -3 -m | python3 -m) pip install utilsx

Running
~~~~~~~

To execute the example scripts that are located in ``examples`` just
execute the following command.

::

    (py -3 | python3) script_name.py

Links
^^^^^

-  `Documentation` (WIP)
-  `dblstatistics.com Discord Sever <https://discord.gg/Qd34uz7qDY>`__
-  `dblstatistics.com
   documentation <https://dblstatistics.com/api/docs>`__

